@@ -2,7 +2,7 @@ from datetime import datetime, timedelta
 from rest_framework.pagination import LimitOffsetPagination
 from rest_framework.generics import ListAPIView
 from rest_framework.response import Response
-from rest_framework.exceptions import NotAcceptable, PermissionDenied
+from rest_framework.exceptions import NotAcceptable
 
 from .mixins import CredentialMixin
 
