@@ -165,9 +165,21 @@ class BaseStatTSVAPIView(CredentialMixin, APIView):
         """
         return None
 
+    def _validate_fields(self, data_fields: list) -> list:
+        values = []
+        serializer = self.get_serializer_class()
+        fields = list(serializer().fields.keys())
+        for f in data_fields:
+            if f in fields:
+                values.append(f)
+            else:
+                raise InvalidFieldsParam(
+                    {"status": "error", "message": f"invalid field - {f}"}
+                )
+        return values
+
     def validate_request_data(self, request) -> dict:
         admin = self.get_check_admin(request)
-        # return Response({"status": "error", "message": "Dont have statistic for this integration"}, status=400)
         if not admin:
             raise PermissionDenied(
                 {
@@ -187,15 +199,7 @@ class BaseStatTSVAPIView(CredentialMixin, APIView):
 
         values = list()
         if 'fields' in data:
-            serializer = self.get_serializer_class()
-            fields = list(serializer().fields.keys())
-            for f in data['fields']:
-                if f in fields:
-                    values.append(f)
-                else:
-                    raise InvalidFieldsParam(
-                        {"status": "error", "message": f"invalid field - {f}"}
-                    )
+            values = self._validate_fields(data['fields'])
         self.check_log()
         return {
             'data': data,
